pub struct SessionController { /* private fields */ }Expand description
Implements a client for the Cloud Dataproc API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
) -> anyhow::Result<()> {
let client = SessionController::builder().build().await?;
let mut list = client.list_sessions()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
The SessionController provides methods to manage interactive sessions.
Configuration
To configure SessionController use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dataproc.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SessionController holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SessionController in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SessionController
impl SessionController
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SessionController.
let client = SessionController::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: SessionController + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: SessionController + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_session(&self) -> CreateSession
pub fn create_session(&self) -> CreateSession
Create an interactive session asynchronously.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataproc_v1::model::Session;
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_session()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_session_id("session_id_value")
.set_session(
Session::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_session(&self) -> GetSession
pub fn get_session(&self) -> GetSession
Gets the resource representation for an interactive session.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController, project_id: &str, location_id: &str, session_id: &str
) -> Result<()> {
let response = client.get_session()
.set_name(format!("projects/{project_id}/locations/{location_id}/sessions/{session_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_sessions(&self) -> ListSessions
pub fn list_sessions(&self) -> ListSessions
Lists interactive sessions.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController, project_id: &str, location_id: &str
) -> Result<()> {
let mut list = client.list_sessions()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn terminate_session(&self) -> TerminateSession
pub fn terminate_session(&self) -> TerminateSession
Terminates the interactive session.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
let response = client.terminate_session()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_session(&self) -> DeleteSession
pub fn delete_session(&self) -> DeleteSession
Deletes the interactive session resource. If the session is not in terminal state, it is terminated, and then deleted.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController, project_id: &str, location_id: &str, session_id: &str
) -> Result<()> {
let response = client.delete_session()
.set_name(format!("projects/{project_id}/locations/{location_id}/sessions/{session_id}"))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dataproc_v1::Result;
async fn sample(
client: &SessionController
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for SessionController
impl Clone for SessionController
Sourcefn clone(&self) -> SessionController
fn clone(&self) -> SessionController
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more