#[non_exhaustive]pub enum FailureAction {
Unspecified,
NoAction,
Delete,
UnknownValue(UnknownValue),
}Expand description
Actions in response to failure of a resource associated with a cluster.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
When FailureAction is unspecified, failure action defaults to NO_ACTION.
NoAction
Take no action on failure to create a cluster resource. NO_ACTION is the default.
Delete
Delete the failed cluster resource.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using FailureAction::value or FailureAction::name.
Implementations