#[non_exhaustive]pub enum Preemptibility {
Unspecified,
NonPreemptible,
Preemptible,
Spot,
UnknownValue(UnknownValue),
}Expand description
Controls the use of preemptible instances within the group.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Preemptibility is unspecified, the system will choose the appropriate setting for each instance group.
NonPreemptible
Instances are non-preemptible.
This option is allowed for all instance groups and is the only valid value for Master and Worker instance groups.
Preemptible
Instances are [preemptible] (https://cloud.google.com/compute/docs/instances/preemptible).
This option is allowed only for [secondary worker] (https://cloud.google.com/dataproc/docs/concepts/compute/secondary-vms) groups.
Spot
Instances are [Spot VMs] (https://cloud.google.com/compute/docs/instances/spot).
This option is allowed only for [secondary worker] (https://cloud.google.com/dataproc/docs/concepts/compute/secondary-vms) groups. Spot VMs are the latest version of [preemptible VMs] (https://cloud.google.com/compute/docs/instances/preemptible), and provide additional features.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Preemptibility::value or Preemptibility::name.
Implementations