#[non_exhaustive]pub struct ConfidentialInstanceConfig {
pub enable_confidential_compute: bool,
pub confidential_instance_type: ConfidentialInstanceType,
/* private fields */
}Expand description
Confidential Instance Config for clusters using Confidential VMs
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_confidential_compute: bool👎Deprecated
Optional. Deprecated: Use ‘confidential_instance_type’ instead. Defines whether the instance should have confidential compute enabled.
confidential_instance_type: ConfidentialInstanceTypeOptional. Defines the type of Confidential Compute technology to use.
Implementations
Sourceimpl ConfidentialInstanceConfig
impl ConfidentialInstanceConfig
Sourcepub fn set_enable_confidential_compute<T: Into<bool>>(self, v: T) -> Self
👎Deprecated
pub fn set_enable_confidential_compute<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_confidential_compute.
Example
ⓘ
let x = ConfidentialInstanceConfig::new().set_enable_confidential_compute(true);Sourcepub fn set_confidential_instance_type<T: Into<ConfidentialInstanceType>>(
self,
v: T,
) -> Self
pub fn set_confidential_instance_type<T: Into<ConfidentialInstanceType>>( self, v: T, ) -> Self
Sets the value of confidential_instance_type.
Example
ⓘ
use google_cloud_dataproc_v1::model::confidential_instance_config::ConfidentialInstanceType;
let x0 = ConfidentialInstanceConfig::new().set_confidential_instance_type(ConfidentialInstanceType::Sev);
let x1 = ConfidentialInstanceConfig::new().set_confidential_instance_type(ConfidentialInstanceType::SevSnp);
let x2 = ConfidentialInstanceConfig::new().set_confidential_instance_type(ConfidentialInstanceType::Tdx);Trait Implementations
Sourceimpl Clone for ConfidentialInstanceConfig
impl Clone for ConfidentialInstanceConfig
Sourcefn clone(&self) -> ConfidentialInstanceConfig
fn clone(&self) -> ConfidentialInstanceConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfidentialInstanceConfig
impl Debug for ConfidentialInstanceConfig
Sourceimpl Default for ConfidentialInstanceConfig
impl Default for ConfidentialInstanceConfig
Sourcefn default() -> ConfidentialInstanceConfig
fn default() -> ConfidentialInstanceConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for ConfidentialInstanceConfig
impl Message for ConfidentialInstanceConfig
impl StructuralPartialEq for ConfidentialInstanceConfig