#[non_exhaustive]pub struct CreateClusterRequest {
pub project_id: String,
pub region: String,
pub cluster: Option<Cluster>,
pub request_id: String,
pub action_on_failed_primary_workers: FailureAction,
/* private fields */
}Expand description
A request to create a cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. The ID of the Google Cloud Platform project that the cluster belongs to.
region: StringRequired. The Dataproc region in which to handle the request.
cluster: Option<Cluster>Required. The cluster to create.
request_id: StringOptional. A unique ID used to identify the request. If the server receives two CreateClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.
It is recommended to always set this value to a UUID.
The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.
action_on_failed_primary_workers: FailureActionOptional. Failure action when primary worker creation fails.
Implementations
Sourceimpl CreateClusterRequest
impl CreateClusterRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = CreateClusterRequest::new().set_project_id("example");Sourcepub fn set_region<T: Into<String>>(self, v: T) -> Self
pub fn set_region<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cluster<T>(self, v: T) -> Self
pub fn set_cluster<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateClusterRequest::new().set_request_id("example");Sourcepub fn set_action_on_failed_primary_workers<T: Into<FailureAction>>(
self,
v: T,
) -> Self
pub fn set_action_on_failed_primary_workers<T: Into<FailureAction>>( self, v: T, ) -> Self
Sets the value of action_on_failed_primary_workers.
Example
use google_cloud_dataproc_v1::model::FailureAction;
let x0 = CreateClusterRequest::new().set_action_on_failed_primary_workers(FailureAction::NoAction);
let x1 = CreateClusterRequest::new().set_action_on_failed_primary_workers(FailureAction::Delete);Trait Implementations
Sourceimpl Clone for CreateClusterRequest
impl Clone for CreateClusterRequest
Sourcefn clone(&self) -> CreateClusterRequest
fn clone(&self) -> CreateClusterRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateClusterRequest
impl Debug for CreateClusterRequest
Sourceimpl Default for CreateClusterRequest
impl Default for CreateClusterRequest
Sourcefn default() -> CreateClusterRequest
fn default() -> CreateClusterRequest
Sourceimpl Message for CreateClusterRequest
impl Message for CreateClusterRequest
Sourceimpl PartialEq for CreateClusterRequest
impl PartialEq for CreateClusterRequest
impl StructuralPartialEq for CreateClusterRequest