#[non_exhaustive]pub struct CreateNodeGroupRequest {
pub parent: String,
pub node_group: Option<NodeGroup>,
pub node_group_id: String,
pub request_id: String,
/* private fields */
}Expand description
A request to create a node group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this node group will be created.
Format: projects/{project}/regions/{region}/clusters/{cluster}
node_group: Option<NodeGroup>Required. The node group to create.
node_group_id: StringOptional. An optional node group ID. Generated if not specified.
The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of from 3 to 33 characters.
request_id: StringOptional. A unique ID used to identify the request. If the server receives two CreateNodeGroupRequest with the same ID, the second request is ignored and the first google.longrunning.Operation created and stored in the backend is returned.
Recommendation: Set this value to a UUID.
The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.
Implementations
Sourceimpl CreateNodeGroupRequest
impl CreateNodeGroupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_node_group<T>(self, v: T) -> Self
pub fn set_node_group<T>(self, v: T) -> Self
Sets the value of node_group.
Example
use google_cloud_dataproc_v1::model::NodeGroup;
let x = CreateNodeGroupRequest::new().set_node_group(NodeGroup::default()/* use setters */);Sourcepub fn set_or_clear_node_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_node_group<T>(self, v: Option<T>) -> Self
Sets or clears the value of node_group.
Example
use google_cloud_dataproc_v1::model::NodeGroup;
let x = CreateNodeGroupRequest::new().set_or_clear_node_group(Some(NodeGroup::default()/* use setters */));
let x = CreateNodeGroupRequest::new().set_or_clear_node_group(None::<NodeGroup>);Sourcepub fn set_node_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_node_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of node_group_id.
Example
let x = CreateNodeGroupRequest::new().set_node_group_id("example");Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateNodeGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateNodeGroupRequest
impl Clone for CreateNodeGroupRequest
Sourcefn clone(&self) -> CreateNodeGroupRequest
fn clone(&self) -> CreateNodeGroupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateNodeGroupRequest
impl Debug for CreateNodeGroupRequest
Sourceimpl Default for CreateNodeGroupRequest
impl Default for CreateNodeGroupRequest
Sourcefn default() -> CreateNodeGroupRequest
fn default() -> CreateNodeGroupRequest
Sourceimpl Message for CreateNodeGroupRequest
impl Message for CreateNodeGroupRequest
Sourceimpl PartialEq for CreateNodeGroupRequest
impl PartialEq for CreateNodeGroupRequest
impl StructuralPartialEq for CreateNodeGroupRequest