#[non_exhaustive]pub struct DeleteClusterRequest {
pub project_id: String,
pub region: String,
pub cluster_name: String,
pub cluster_uuid: String,
pub request_id: String,
/* private fields */
}Expand description
A request to delete a cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. The ID of the Google Cloud Platform project that the cluster belongs to.
region: StringRequired. The Dataproc region in which to handle the request.
cluster_name: StringRequired. The cluster name.
cluster_uuid: StringOptional. Specifying the cluster_uuid means the RPC should fail
(with error NOT_FOUND) if cluster with specified UUID does not exist.
request_id: StringOptional. A unique ID used to identify the request. If the server receives two DeleteClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.
It is recommended to always set this value to a UUID.
The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.
Implementations
Sourceimpl DeleteClusterRequest
impl DeleteClusterRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = DeleteClusterRequest::new().set_project_id("example");Sourcepub fn set_region<T: Into<String>>(self, v: T) -> Self
pub fn set_region<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cluster_name<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_name<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_name.
Example
let x = DeleteClusterRequest::new().set_cluster_name("example");Sourcepub fn set_cluster_uuid<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_uuid<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_uuid.
Example
let x = DeleteClusterRequest::new().set_cluster_uuid("example");Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeleteClusterRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for DeleteClusterRequest
impl Clone for DeleteClusterRequest
Sourcefn clone(&self) -> DeleteClusterRequest
fn clone(&self) -> DeleteClusterRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DeleteClusterRequest
impl Debug for DeleteClusterRequest
Sourceimpl Default for DeleteClusterRequest
impl Default for DeleteClusterRequest
Sourcefn default() -> DeleteClusterRequest
fn default() -> DeleteClusterRequest
Sourceimpl Message for DeleteClusterRequest
impl Message for DeleteClusterRequest
Sourceimpl PartialEq for DeleteClusterRequest
impl PartialEq for DeleteClusterRequest
impl StructuralPartialEq for DeleteClusterRequest