#[non_exhaustive]pub struct DiskConfig {
pub boot_disk_type: String,
pub boot_disk_size_gb: i32,
pub num_local_ssds: i32,
pub local_ssd_interface: String,
pub boot_disk_provisioned_iops: Option<i64>,
pub boot_disk_provisioned_throughput: Option<i64>,
pub attached_disk_configs: Vec<AttachedDiskConfig>,
/* private fields */
}Expand description
Specifies the config of boot disk and attached disk options for a group of VM instances.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.boot_disk_type: StringOptional. Type of the boot disk (default is pd-standard).
Valid values: pd-balanced (Persistent Disk Balanced Solid State Drive),
pd-ssd (Persistent Disk Solid State Drive),
or pd-standard (Persistent Disk Hard Disk Drive).
See Disk types.
boot_disk_size_gb: i32Optional. Size in GB of the boot disk (default is 500GB).
num_local_ssds: i32Optional. Number of attached SSDs, from 0 to 8 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries.
Note: Local SSD options may vary by machine type and number of vCPUs selected.
local_ssd_interface: StringOptional. Interface type of local SSDs (default is scsi).
Valid values: scsi (Small Computer System Interface),
nvme (Non-Volatile Memory Express).
See local SSD
performance.
boot_disk_provisioned_iops: Option<i64>Optional. Indicates how many IOPS to provision for the disk. This sets the
number of I/O operations per second that the disk can handle.
This field is supported only if
boot_disk_type is
hyperdisk-balanced.
boot_disk_provisioned_throughput: Option<i64>Optional. Indicates how much throughput to provision for the disk. This
sets the number of throughput mb per second that the disk can handle.
Values must be greater than or equal to 1. This field is supported only
if boot_disk_type is
hyperdisk-balanced.
attached_disk_configs: Vec<AttachedDiskConfig>Optional. A list of attached disk configs for a group of VM instances.
Implementations
Sourceimpl DiskConfig
impl DiskConfig
Sourcepub fn set_boot_disk_type<T: Into<String>>(self, v: T) -> Self
pub fn set_boot_disk_type<T: Into<String>>(self, v: T) -> Self
Sets the value of boot_disk_type.
Example
let x = DiskConfig::new().set_boot_disk_type("example");Sourcepub fn set_boot_disk_size_gb<T: Into<i32>>(self, v: T) -> Self
pub fn set_boot_disk_size_gb<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_num_local_ssds<T: Into<i32>>(self, v: T) -> Self
pub fn set_num_local_ssds<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_local_ssd_interface<T: Into<String>>(self, v: T) -> Self
pub fn set_local_ssd_interface<T: Into<String>>(self, v: T) -> Self
Sets the value of local_ssd_interface.
Example
let x = DiskConfig::new().set_local_ssd_interface("example");Sourcepub fn set_boot_disk_provisioned_iops<T>(self, v: T) -> Self
pub fn set_boot_disk_provisioned_iops<T>(self, v: T) -> Self
Sets the value of boot_disk_provisioned_iops.
Example
let x = DiskConfig::new().set_boot_disk_provisioned_iops(42);Sourcepub fn set_or_clear_boot_disk_provisioned_iops<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_boot_disk_provisioned_iops<T>(self, v: Option<T>) -> Self
Sets or clears the value of boot_disk_provisioned_iops.
Example
let x = DiskConfig::new().set_or_clear_boot_disk_provisioned_iops(Some(42));
let x = DiskConfig::new().set_or_clear_boot_disk_provisioned_iops(None::<i32>);Sourcepub fn set_boot_disk_provisioned_throughput<T>(self, v: T) -> Self
pub fn set_boot_disk_provisioned_throughput<T>(self, v: T) -> Self
Sets the value of boot_disk_provisioned_throughput.
Example
let x = DiskConfig::new().set_boot_disk_provisioned_throughput(42);Sourcepub fn set_or_clear_boot_disk_provisioned_throughput<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_boot_disk_provisioned_throughput<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of boot_disk_provisioned_throughput.
Example
let x = DiskConfig::new().set_or_clear_boot_disk_provisioned_throughput(Some(42));
let x = DiskConfig::new().set_or_clear_boot_disk_provisioned_throughput(None::<i32>);Sourcepub fn set_attached_disk_configs<T, V>(self, v: T) -> Self
pub fn set_attached_disk_configs<T, V>(self, v: T) -> Self
Sets the value of attached_disk_configs.
Example
use google_cloud_dataproc_v1::model::AttachedDiskConfig;
let x = DiskConfig::new()
.set_attached_disk_configs([
AttachedDiskConfig::default()/* use setters */,
AttachedDiskConfig::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for DiskConfig
impl Clone for DiskConfig
Sourcefn clone(&self) -> DiskConfig
fn clone(&self) -> DiskConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DiskConfig
impl Debug for DiskConfig
Sourceimpl Default for DiskConfig
impl Default for DiskConfig
Sourcefn default() -> DiskConfig
fn default() -> DiskConfig
Sourceimpl PartialEq for DiskConfig
impl PartialEq for DiskConfig
impl StructuralPartialEq for DiskConfig