#[non_exhaustive]pub struct EncryptionConfig {
pub gce_pd_kms_key_name: String,
pub kms_key: String,
/* private fields */
}Expand description
Encryption settings for the cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.gce_pd_kms_key_name: StringOptional. The Cloud KMS key resource name to use for persistent disk encryption for all instances in the cluster. See [Use CMEK with cluster data] (https://cloud.google.com//dataproc/docs/concepts/configuring-clusters/customer-managed-encryption#use_cmek_with_cluster_data) for more information.
kms_key: StringOptional. The Cloud KMS key resource name to use for cluster persistent disk and job argument encryption. See [Use CMEK with cluster data] (https://cloud.google.com//dataproc/docs/concepts/configuring-clusters/customer-managed-encryption#use_cmek_with_cluster_data) for more information.
When this key resource name is provided, the following job arguments of the following job types submitted to the cluster are encrypted using CMEK:
- FlinkJob args
- HadoopJob args
- SparkJob args
- SparkRJob args
- PySparkJob args
- SparkSqlJob scriptVariables and queryList.queries
- HiveJob scriptVariables and queryList.queries
- PigJob scriptVariables and queryList.queries
- PrestoJob scriptVariables and queryList.queries
Implementations
Sourceimpl EncryptionConfig
impl EncryptionConfig
Sourcepub fn set_gce_pd_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_gce_pd_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sets the value of gce_pd_kms_key_name.
Example
let x = EncryptionConfig::new().set_gce_pd_kms_key_name("example");Trait Implementations
Sourceimpl Clone for EncryptionConfig
impl Clone for EncryptionConfig
Sourcefn clone(&self) -> EncryptionConfig
fn clone(&self) -> EncryptionConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EncryptionConfig
impl Debug for EncryptionConfig
Sourceimpl Default for EncryptionConfig
impl Default for EncryptionConfig
Sourcefn default() -> EncryptionConfig
fn default() -> EncryptionConfig
Sourceimpl Message for EncryptionConfig
impl Message for EncryptionConfig
Sourceimpl PartialEq for EncryptionConfig
impl PartialEq for EncryptionConfig
impl StructuralPartialEq for EncryptionConfig