#[non_exhaustive]pub struct JobScheduling {
pub max_failures_per_hour: i32,
pub max_failures_total: i32,
/* private fields */
}Expand description
Job scheduling options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_failures_per_hour: i32Optional. Maximum number of times per hour a driver can be restarted as a result of driver exiting with non-zero code before job is reported failed.
A job might be reported as thrashing if the driver exits with a non-zero code four times within a 10-minute window.
Maximum value is 10.
Note: This restartable job option is not supported in Dataproc [workflow templates] (https://cloud.google.com/dataproc/docs/concepts/workflows/using-workflows#adding_jobs_to_a_template).
max_failures_total: i32Optional. Maximum total number of times a driver can be restarted as a result of the driver exiting with a non-zero code. After the maximum number is reached, the job will be reported as failed.
Maximum value is 240.
Note: Currently, this restartable job option is not supported in Dataproc workflow templates.
Implementations
Sourceimpl JobScheduling
impl JobScheduling
Sourcepub fn set_max_failures_per_hour<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_failures_per_hour<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_failures_per_hour.
Example
let x = JobScheduling::new().set_max_failures_per_hour(42);Sourcepub fn set_max_failures_total<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_failures_total<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_failures_total.
Example
let x = JobScheduling::new().set_max_failures_total(42);Trait Implementations
Sourceimpl Clone for JobScheduling
impl Clone for JobScheduling
Sourcefn clone(&self) -> JobScheduling
fn clone(&self) -> JobScheduling
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for JobScheduling
impl Debug for JobScheduling
Sourceimpl Default for JobScheduling
impl Default for JobScheduling
Sourcefn default() -> JobScheduling
fn default() -> JobScheduling
Sourceimpl Message for JobScheduling
impl Message for JobScheduling
Sourceimpl PartialEq for JobScheduling
impl PartialEq for JobScheduling
impl StructuralPartialEq for JobScheduling