#[non_exhaustive]pub struct KerberosConfig {Show 15 fields
pub enable_kerberos: bool,
pub root_principal_password_uri: String,
pub kms_key_uri: String,
pub keystore_uri: String,
pub truststore_uri: String,
pub keystore_password_uri: String,
pub key_password_uri: String,
pub truststore_password_uri: String,
pub cross_realm_trust_realm: String,
pub cross_realm_trust_kdc: String,
pub cross_realm_trust_admin_server: String,
pub cross_realm_trust_shared_password_uri: String,
pub kdc_db_key_uri: String,
pub tgt_lifetime_hours: i32,
pub realm: String,
/* private fields */
}Expand description
Specifies Kerberos related configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_kerberos: boolOptional. Flag to indicate whether to Kerberize the cluster (default: false). Set this field to true to enable Kerberos on a cluster.
root_principal_password_uri: StringOptional. The Cloud Storage URI of a KMS encrypted file containing the root principal password.
kms_key_uri: StringOptional. The URI of the KMS key used to encrypt sensitive files.
keystore_uri: StringOptional. The Cloud Storage URI of the keystore file used for SSL encryption. If not provided, Dataproc will provide a self-signed certificate.
truststore_uri: StringOptional. The Cloud Storage URI of the truststore file used for SSL encryption. If not provided, Dataproc will provide a self-signed certificate.
keystore_password_uri: StringOptional. The Cloud Storage URI of a KMS encrypted file containing the password to the user provided keystore. For the self-signed certificate, this password is generated by Dataproc.
key_password_uri: StringOptional. The Cloud Storage URI of a KMS encrypted file containing the password to the user provided key. For the self-signed certificate, this password is generated by Dataproc.
truststore_password_uri: StringOptional. The Cloud Storage URI of a KMS encrypted file containing the password to the user provided truststore. For the self-signed certificate, this password is generated by Dataproc.
cross_realm_trust_realm: StringOptional. The remote realm the Dataproc on-cluster KDC will trust, should the user enable cross realm trust.
cross_realm_trust_kdc: StringOptional. The KDC (IP or hostname) for the remote trusted realm in a cross realm trust relationship.
cross_realm_trust_admin_server: StringOptional. The admin server (IP or hostname) for the remote trusted realm in a cross realm trust relationship.
Optional. The Cloud Storage URI of a KMS encrypted file containing the shared password between the on-cluster Kerberos realm and the remote trusted realm, in a cross realm trust relationship.
kdc_db_key_uri: StringOptional. The Cloud Storage URI of a KMS encrypted file containing the master key of the KDC database.
tgt_lifetime_hours: i32Optional. The lifetime of the ticket granting ticket, in hours. If not specified, or user specifies 0, then default value 10 will be used.
realm: StringOptional. The name of the on-cluster Kerberos realm. If not specified, the uppercased domain of hostnames will be the realm.
Implementations
Sourceimpl KerberosConfig
impl KerberosConfig
Sourcepub fn set_enable_kerberos<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_kerberos<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_kerberos.
Example
let x = KerberosConfig::new().set_enable_kerberos(true);Sourcepub fn set_root_principal_password_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_root_principal_password_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of root_principal_password_uri.
Example
let x = KerberosConfig::new().set_root_principal_password_uri("example");Sourcepub fn set_kms_key_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_keystore_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_keystore_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of keystore_uri.
Example
let x = KerberosConfig::new().set_keystore_uri("example");Sourcepub fn set_truststore_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_truststore_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of truststore_uri.
Example
let x = KerberosConfig::new().set_truststore_uri("example");Sourcepub fn set_keystore_password_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_keystore_password_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of keystore_password_uri.
Example
let x = KerberosConfig::new().set_keystore_password_uri("example");Sourcepub fn set_key_password_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_key_password_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of key_password_uri.
Example
let x = KerberosConfig::new().set_key_password_uri("example");Sourcepub fn set_truststore_password_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_truststore_password_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of truststore_password_uri.
Example
let x = KerberosConfig::new().set_truststore_password_uri("example");Sourcepub fn set_cross_realm_trust_realm<T: Into<String>>(self, v: T) -> Self
pub fn set_cross_realm_trust_realm<T: Into<String>>(self, v: T) -> Self
Sets the value of cross_realm_trust_realm.
Example
let x = KerberosConfig::new().set_cross_realm_trust_realm("example");Sourcepub fn set_cross_realm_trust_kdc<T: Into<String>>(self, v: T) -> Self
pub fn set_cross_realm_trust_kdc<T: Into<String>>(self, v: T) -> Self
Sets the value of cross_realm_trust_kdc.
Example
let x = KerberosConfig::new().set_cross_realm_trust_kdc("example");Sourcepub fn set_cross_realm_trust_admin_server<T: Into<String>>(self, v: T) -> Self
pub fn set_cross_realm_trust_admin_server<T: Into<String>>(self, v: T) -> Self
Sets the value of cross_realm_trust_admin_server.
Example
let x = KerberosConfig::new().set_cross_realm_trust_admin_server("example");Sets the value of cross_realm_trust_shared_password_uri.
Example
let x = KerberosConfig::new().set_cross_realm_trust_shared_password_uri("example");Sourcepub fn set_kdc_db_key_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_kdc_db_key_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of kdc_db_key_uri.
Example
let x = KerberosConfig::new().set_kdc_db_key_uri("example");Sourcepub fn set_tgt_lifetime_hours<T: Into<i32>>(self, v: T) -> Self
pub fn set_tgt_lifetime_hours<T: Into<i32>>(self, v: T) -> Self
Sets the value of tgt_lifetime_hours.
Example
let x = KerberosConfig::new().set_tgt_lifetime_hours(42);Trait Implementations
Sourceimpl Clone for KerberosConfig
impl Clone for KerberosConfig
Sourcefn clone(&self) -> KerberosConfig
fn clone(&self) -> KerberosConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for KerberosConfig
impl Debug for KerberosConfig
Sourceimpl Default for KerberosConfig
impl Default for KerberosConfig
Sourcefn default() -> KerberosConfig
fn default() -> KerberosConfig
Sourceimpl Message for KerberosConfig
impl Message for KerberosConfig
Sourceimpl PartialEq for KerberosConfig
impl PartialEq for KerberosConfig
impl StructuralPartialEq for KerberosConfig