#[non_exhaustive]pub struct ListClustersRequest {
pub project_id: String,
pub region: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
A request to list the clusters in a project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. The ID of the Google Cloud Platform project that the cluster belongs to.
region: StringRequired. The Dataproc region in which to handle the request.
filter: StringOptional. A filter constraining the clusters to list. Filters are case-sensitive and have the following syntax:
field = value [AND [field = value]] …
where field is one of status.state, clusterName, or labels.[KEY],
and [KEY] is a label key. value can be * to match all values.
status.state can be one of the following: ACTIVE, INACTIVE,
CREATING, RUNNING, ERROR, DELETING, UPDATING, STOPPING, or
STOPPED. ACTIVE contains the CREATING, UPDATING, and RUNNING
states. INACTIVE contains the DELETING, ERROR, STOPPING, and
STOPPED states. clusterName is the name of the cluster provided at
creation time. Only the logical AND operator is supported;
space-separated items are treated as having an implicit AND operator.
Example filter:
status.state = ACTIVE AND clusterName = mycluster AND labels.env = staging AND labels.starred = *
page_size: i32Optional. The standard List page size.
page_token: StringOptional. The standard List page token.
Implementations
Sourceimpl ListClustersRequest
impl ListClustersRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = ListClustersRequest::new().set_project_id("example");Sourcepub fn set_region<T: Into<String>>(self, v: T) -> Self
pub fn set_region<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListClustersRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListClustersRequest
impl Clone for ListClustersRequest
Sourcefn clone(&self) -> ListClustersRequest
fn clone(&self) -> ListClustersRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListClustersRequest
impl Debug for ListClustersRequest
Sourceimpl Default for ListClustersRequest
impl Default for ListClustersRequest
Sourcefn default() -> ListClustersRequest
fn default() -> ListClustersRequest
Sourceimpl Message for ListClustersRequest
impl Message for ListClustersRequest
Sourceimpl PartialEq for ListClustersRequest
impl PartialEq for ListClustersRequest
impl StructuralPartialEq for ListClustersRequest