#[non_exhaustive]pub struct ListSessionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
A request to list sessions in a project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of sessions.
page_size: i32Optional. The maximum number of sessions to return in each response. The service may return fewer than this value.
page_token: StringOptional. A page token received from a previous ListSessions call.
Provide this token to retrieve the subsequent page.
filter: StringOptional. A filter for the sessions to return in the response.
A filter is a logical expression constraining the values of various fields
in each session resource. Filters are case sensitive, and may contain
multiple clauses combined with logical operators (AND, OR).
Supported fields are session_id, session_uuid, state, create_time,
and labels.
Example: state = ACTIVE and create_time < "2023-01-01T00:00:00Z"
is a filter for sessions in an ACTIVE state that were created before
2023-01-01. state = ACTIVE and labels.environment=production is a filter
for sessions in an ACTIVE state that have a production environment label.
See https://google.aip.dev/assets/misc/ebnf-filtering.txt for a detailed description of the filter syntax and a list of supported comparators.
Implementations
Sourceimpl ListSessionsRequest
impl ListSessionsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSessionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSessionsRequest
impl Clone for ListSessionsRequest
Sourcefn clone(&self) -> ListSessionsRequest
fn clone(&self) -> ListSessionsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListSessionsRequest
impl Debug for ListSessionsRequest
Sourceimpl Default for ListSessionsRequest
impl Default for ListSessionsRequest
Sourcefn default() -> ListSessionsRequest
fn default() -> ListSessionsRequest
Sourceimpl Message for ListSessionsRequest
impl Message for ListSessionsRequest
Sourceimpl PartialEq for ListSessionsRequest
impl PartialEq for ListSessionsRequest
impl StructuralPartialEq for ListSessionsRequest