#[non_exhaustive]pub struct ManagedCluster {
pub cluster_name: String,
pub config: Option<ClusterConfig>,
pub labels: HashMap<String, String>,
/* private fields */
}Expand description
Cluster that is managed by the workflow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_name: StringRequired. The cluster name prefix. A unique cluster name will be formed by appending a random suffix.
The name must contain only lower-case letters (a-z), numbers (0-9), and hyphens (-). Must begin with a letter. Cannot begin or end with hyphen. Must consist of between 2 and 35 characters.
config: Option<ClusterConfig>Required. The cluster configuration.
labels: HashMap<String, String>Optional. The labels to associate with this cluster.
Label keys must be between 1 and 63 characters long, and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
Label values must be between 1 and 63 characters long, and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
No more than 32 labels can be associated with a given cluster.
Implementations
Sourceimpl ManagedCluster
impl ManagedCluster
Sourcepub fn set_cluster_name<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_name<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_name.
Example
let x = ManagedCluster::new().set_cluster_name("example");Sourcepub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<ClusterConfig>,
pub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<ClusterConfig>,
Sourcepub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ClusterConfig>,
pub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ClusterConfig>,