#[non_exhaustive]pub struct PySparkJob {
pub main_python_file_uri: String,
pub args: Vec<String>,
pub python_file_uris: Vec<String>,
pub jar_file_uris: Vec<String>,
pub file_uris: Vec<String>,
pub archive_uris: Vec<String>,
pub properties: HashMap<String, String>,
pub logging_config: Option<LoggingConfig>,
/* private fields */
}Expand description
A Dataproc job for running Apache PySpark applications on YARN.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.main_python_file_uri: StringRequired. The HCFS URI of the main Python file to use as the driver. Must be a .py file.
args: Vec<String>Optional. The arguments to pass to the driver. Do not include arguments,
such as --conf, that can be set as job properties, since a collision may
occur that causes an incorrect job submission.
python_file_uris: Vec<String>Optional. HCFS file URIs of Python files to pass to the PySpark framework. Supported file types: .py, .egg, and .zip.
jar_file_uris: Vec<String>Optional. HCFS URIs of jar files to add to the CLASSPATHs of the Python driver and tasks.
file_uris: Vec<String>Optional. HCFS URIs of files to be placed in the working directory of each executor. Useful for naively parallel tasks.
archive_uris: Vec<String>Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
properties: HashMap<String, String>Optional. A mapping of property names to values, used to configure PySpark. Properties that conflict with values set by the Dataproc API might be overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf and classes in user code.
logging_config: Option<LoggingConfig>Optional. The runtime log config for job execution.
Implementations
Sourceimpl PySparkJob
impl PySparkJob
Sourcepub fn set_main_python_file_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_main_python_file_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of main_python_file_uri.
Example
let x = PySparkJob::new().set_main_python_file_uri("example");Sourcepub fn set_python_file_uris<T, V>(self, v: T) -> Self
pub fn set_python_file_uris<T, V>(self, v: T) -> Self
Sets the value of python_file_uris.
Example
let x = PySparkJob::new().set_python_file_uris(["a", "b", "c"]);Sourcepub fn set_jar_file_uris<T, V>(self, v: T) -> Self
pub fn set_jar_file_uris<T, V>(self, v: T) -> Self
Sets the value of jar_file_uris.
Example
let x = PySparkJob::new().set_jar_file_uris(["a", "b", "c"]);Sourcepub fn set_file_uris<T, V>(self, v: T) -> Self
pub fn set_file_uris<T, V>(self, v: T) -> Self
Sourcepub fn set_archive_uris<T, V>(self, v: T) -> Self
pub fn set_archive_uris<T, V>(self, v: T) -> Self
Sets the value of archive_uris.
Example
let x = PySparkJob::new().set_archive_uris(["a", "b", "c"]);Sourcepub fn set_properties<T, K, V>(self, v: T) -> Self
pub fn set_properties<T, K, V>(self, v: T) -> Self
Sets the value of properties.
Example
let x = PySparkJob::new().set_properties([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_logging_config<T>(self, v: T) -> Selfwhere
T: Into<LoggingConfig>,
pub fn set_logging_config<T>(self, v: T) -> Selfwhere
T: Into<LoggingConfig>,
Sets the value of logging_config.
Example
use google_cloud_dataproc_v1::model::LoggingConfig;
let x = PySparkJob::new().set_logging_config(LoggingConfig::default()/* use setters */);Sourcepub fn set_or_clear_logging_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingConfig>,
pub fn set_or_clear_logging_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingConfig>,
Sets or clears the value of logging_config.
Example
use google_cloud_dataproc_v1::model::LoggingConfig;
let x = PySparkJob::new().set_or_clear_logging_config(Some(LoggingConfig::default()/* use setters */));
let x = PySparkJob::new().set_or_clear_logging_config(None::<LoggingConfig>);Trait Implementations
Sourceimpl Clone for PySparkJob
impl Clone for PySparkJob
Sourcefn clone(&self) -> PySparkJob
fn clone(&self) -> PySparkJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PySparkJob
impl Debug for PySparkJob
Sourceimpl Default for PySparkJob
impl Default for PySparkJob
Sourcefn default() -> PySparkJob
fn default() -> PySparkJob
Sourceimpl PartialEq for PySparkJob
impl PartialEq for PySparkJob
impl StructuralPartialEq for PySparkJob