#[non_exhaustive]pub struct RuntimeInfo {
pub endpoints: HashMap<String, String>,
pub output_uri: String,
pub diagnostic_output_uri: String,
pub approximate_usage: Option<UsageMetrics>,
pub current_usage: Option<UsageSnapshot>,
/* private fields */
}Expand description
Runtime information about workload execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoints: HashMap<String, String>Output only. Map of remote access endpoints (such as web interfaces and APIs) to their URIs.
output_uri: StringOutput only. A URI pointing to the location of the stdout and stderr of the workload.
diagnostic_output_uri: StringOutput only. A URI pointing to the location of the diagnostics tarball.
approximate_usage: Option<UsageMetrics>Output only. Approximate workload resource usage, calculated when the workload completes (see [Dataproc Serverless pricing] (https://cloud.google.com/dataproc-serverless/pricing)).
Note: This metric calculation may change in the future, for example, to capture cumulative workload resource consumption during workload execution (see the [Dataproc Serverless release notes] (https://cloud.google.com/dataproc-serverless/docs/release-notes) for announcements, changes, fixes and other Dataproc developments).
current_usage: Option<UsageSnapshot>Output only. Snapshot of current workload resource usage.
Implementations
Sourceimpl RuntimeInfo
impl RuntimeInfo
Sourcepub fn set_endpoints<T, K, V>(self, v: T) -> Self
pub fn set_endpoints<T, K, V>(self, v: T) -> Self
Sourcepub fn set_output_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_output_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_diagnostic_output_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_diagnostic_output_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of diagnostic_output_uri.
Example
let x = RuntimeInfo::new().set_diagnostic_output_uri("example");Sourcepub fn set_approximate_usage<T>(self, v: T) -> Selfwhere
T: Into<UsageMetrics>,
pub fn set_approximate_usage<T>(self, v: T) -> Selfwhere
T: Into<UsageMetrics>,
Sets the value of approximate_usage.
Example
use google_cloud_dataproc_v1::model::UsageMetrics;
let x = RuntimeInfo::new().set_approximate_usage(UsageMetrics::default()/* use setters */);Sourcepub fn set_or_clear_approximate_usage<T>(self, v: Option<T>) -> Selfwhere
T: Into<UsageMetrics>,
pub fn set_or_clear_approximate_usage<T>(self, v: Option<T>) -> Selfwhere
T: Into<UsageMetrics>,
Sets or clears the value of approximate_usage.
Example
use google_cloud_dataproc_v1::model::UsageMetrics;
let x = RuntimeInfo::new().set_or_clear_approximate_usage(Some(UsageMetrics::default()/* use setters */));
let x = RuntimeInfo::new().set_or_clear_approximate_usage(None::<UsageMetrics>);Sourcepub fn set_current_usage<T>(self, v: T) -> Selfwhere
T: Into<UsageSnapshot>,
pub fn set_current_usage<T>(self, v: T) -> Selfwhere
T: Into<UsageSnapshot>,
Sets the value of current_usage.
Example
use google_cloud_dataproc_v1::model::UsageSnapshot;
let x = RuntimeInfo::new().set_current_usage(UsageSnapshot::default()/* use setters */);Sourcepub fn set_or_clear_current_usage<T>(self, v: Option<T>) -> Selfwhere
T: Into<UsageSnapshot>,
pub fn set_or_clear_current_usage<T>(self, v: Option<T>) -> Selfwhere
T: Into<UsageSnapshot>,
Sets or clears the value of current_usage.
Example
use google_cloud_dataproc_v1::model::UsageSnapshot;
let x = RuntimeInfo::new().set_or_clear_current_usage(Some(UsageSnapshot::default()/* use setters */));
let x = RuntimeInfo::new().set_or_clear_current_usage(None::<UsageSnapshot>);Trait Implementations
Sourceimpl Clone for RuntimeInfo
impl Clone for RuntimeInfo
Sourcefn clone(&self) -> RuntimeInfo
fn clone(&self) -> RuntimeInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RuntimeInfo
impl Debug for RuntimeInfo
Sourceimpl Default for RuntimeInfo
impl Default for RuntimeInfo
Sourcefn default() -> RuntimeInfo
fn default() -> RuntimeInfo
Sourceimpl Message for RuntimeInfo
impl Message for RuntimeInfo
Sourceimpl PartialEq for RuntimeInfo
impl PartialEq for RuntimeInfo
impl StructuralPartialEq for RuntimeInfo