#[non_exhaustive]pub struct SparkJob {
pub args: Vec<String>,
pub jar_file_uris: Vec<String>,
pub file_uris: Vec<String>,
pub archive_uris: Vec<String>,
pub properties: HashMap<String, String>,
pub logging_config: Option<LoggingConfig>,
pub driver: Option<Driver>,
/* private fields */
}Expand description
A Dataproc job for running Apache Spark applications on YARN.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.args: Vec<String>Optional. The arguments to pass to the driver. Do not include arguments,
such as --conf, that can be set as job properties, since a collision may
occur that causes an incorrect job submission.
jar_file_uris: Vec<String>Optional. HCFS URIs of jar files to add to the CLASSPATHs of the Spark driver and tasks.
file_uris: Vec<String>Optional. HCFS URIs of files to be placed in the working directory of each executor. Useful for naively parallel tasks.
archive_uris: Vec<String>Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
properties: HashMap<String, String>Optional. A mapping of property names to values, used to configure Spark. Properties that conflict with values set by the Dataproc API might be overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf and classes in user code.
logging_config: Option<LoggingConfig>Optional. The runtime log config for job execution.
driver: Option<Driver>Required. The specification of the main method to call to drive the job. Specify either the jar file that contains the main class or the main class name. To pass both a main jar and a main class in that jar, add the jar to jarFileUris, and then specify the main class name in mainClass.
Implementations
Sourceimpl SparkJob
impl SparkJob
Sourcepub fn set_jar_file_uris<T, V>(self, v: T) -> Self
pub fn set_jar_file_uris<T, V>(self, v: T) -> Self
Sets the value of jar_file_uris.
Example
let x = SparkJob::new().set_jar_file_uris(["a", "b", "c"]);Sourcepub fn set_file_uris<T, V>(self, v: T) -> Self
pub fn set_file_uris<T, V>(self, v: T) -> Self
Sourcepub fn set_archive_uris<T, V>(self, v: T) -> Self
pub fn set_archive_uris<T, V>(self, v: T) -> Self
Sets the value of archive_uris.
Example
let x = SparkJob::new().set_archive_uris(["a", "b", "c"]);Sourcepub fn set_properties<T, K, V>(self, v: T) -> Self
pub fn set_properties<T, K, V>(self, v: T) -> Self
Sets the value of properties.
Example
let x = SparkJob::new().set_properties([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_logging_config<T>(self, v: T) -> Selfwhere
T: Into<LoggingConfig>,
pub fn set_logging_config<T>(self, v: T) -> Selfwhere
T: Into<LoggingConfig>,
Sets the value of logging_config.
Example
use google_cloud_dataproc_v1::model::LoggingConfig;
let x = SparkJob::new().set_logging_config(LoggingConfig::default()/* use setters */);Sourcepub fn set_or_clear_logging_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingConfig>,
pub fn set_or_clear_logging_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingConfig>,
Sets or clears the value of logging_config.
Example
use google_cloud_dataproc_v1::model::LoggingConfig;
let x = SparkJob::new().set_or_clear_logging_config(Some(LoggingConfig::default()/* use setters */));
let x = SparkJob::new().set_or_clear_logging_config(None::<LoggingConfig>);Sourcepub fn set_driver<T: Into<Option<Driver>>>(self, v: T) -> Self
pub fn set_driver<T: Into<Option<Driver>>>(self, v: T) -> Self
Sourcepub fn main_jar_file_uri(&self) -> Option<&String>
pub fn main_jar_file_uri(&self) -> Option<&String>
The value of driver
if it holds a MainJarFileUri, None if the field is not set or
holds a different branch.
Sourcepub fn set_main_jar_file_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_main_jar_file_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn main_class(&self) -> Option<&String>
pub fn main_class(&self) -> Option<&String>
The value of driver
if it holds a MainClass, None if the field is not set or
holds a different branch.
Sourcepub fn set_main_class<T: Into<String>>(self, v: T) -> Self
pub fn set_main_class<T: Into<String>>(self, v: T) -> Self