#[non_exhaustive]pub struct WorkflowTemplatePlacement {
pub placement: Option<Placement>,
/* private fields */
}Expand description
Specifies workflow execution target.
Either managed_cluster or cluster_selector is required.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.placement: Option<Placement>Required. Specifies where workflow executes; either on a managed cluster or an existing cluster chosen by labels.
Implementations
Sourceimpl WorkflowTemplatePlacement
impl WorkflowTemplatePlacement
Sourcepub fn set_placement<T: Into<Option<Placement>>>(self, v: T) -> Self
pub fn set_placement<T: Into<Option<Placement>>>(self, v: T) -> Self
Sets the value of placement.
Note that all the setters affecting placement are mutually
exclusive.
Example
use google_cloud_dataproc_v1::model::ManagedCluster;
let x = WorkflowTemplatePlacement::new().set_placement(Some(
google_cloud_dataproc_v1::model::workflow_template_placement::Placement::ManagedCluster(ManagedCluster::default().into())));Sourcepub fn managed_cluster(&self) -> Option<&Box<ManagedCluster>>
pub fn managed_cluster(&self) -> Option<&Box<ManagedCluster>>
The value of placement
if it holds a ManagedCluster, None if the field is not set or
holds a different branch.
Sourcepub fn set_managed_cluster<T: Into<Box<ManagedCluster>>>(self, v: T) -> Self
pub fn set_managed_cluster<T: Into<Box<ManagedCluster>>>(self, v: T) -> Self
Sets the value of placement
to hold a ManagedCluster.
Note that all the setters affecting placement are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::ManagedCluster;
let x = WorkflowTemplatePlacement::new().set_managed_cluster(ManagedCluster::default()/* use setters */);
assert!(x.managed_cluster().is_some());
assert!(x.cluster_selector().is_none());Sourcepub fn cluster_selector(&self) -> Option<&Box<ClusterSelector>>
pub fn cluster_selector(&self) -> Option<&Box<ClusterSelector>>
The value of placement
if it holds a ClusterSelector, None if the field is not set or
holds a different branch.
Sourcepub fn set_cluster_selector<T: Into<Box<ClusterSelector>>>(self, v: T) -> Self
pub fn set_cluster_selector<T: Into<Box<ClusterSelector>>>(self, v: T) -> Self
Sets the value of placement
to hold a ClusterSelector.
Note that all the setters affecting placement are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::ClusterSelector;
let x = WorkflowTemplatePlacement::new().set_cluster_selector(ClusterSelector::default()/* use setters */);
assert!(x.cluster_selector().is_some());
assert!(x.managed_cluster().is_none());Trait Implementations
Sourceimpl Clone for WorkflowTemplatePlacement
impl Clone for WorkflowTemplatePlacement
Sourcefn clone(&self) -> WorkflowTemplatePlacement
fn clone(&self) -> WorkflowTemplatePlacement
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkflowTemplatePlacement
impl Debug for WorkflowTemplatePlacement
Sourceimpl Default for WorkflowTemplatePlacement
impl Default for WorkflowTemplatePlacement
Sourcefn default() -> WorkflowTemplatePlacement
fn default() -> WorkflowTemplatePlacement
Sourceimpl Message for WorkflowTemplatePlacement
impl Message for WorkflowTemplatePlacement
impl StructuralPartialEq for WorkflowTemplatePlacement