#[non_exhaustive]pub struct YarnApplication {
pub name: String,
pub state: State,
pub progress: f32,
pub tracking_url: String,
pub vcore_seconds: i64,
pub memory_mb_seconds: i64,
/* private fields */
}Expand description
A YARN application created by a job. Application information is a subset of <code>org.apache.hadoop.yarn.proto.YarnProtos.ApplicationReportProto</code>.
Beta Feature: This report is available for testing purposes only. It may be changed before final release.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The application name.
state: StateRequired. The application state.
progress: f32Required. The numerical progress of the application, from 1 to 100.
tracking_url: StringOptional. The HTTP URL of the ApplicationMaster, HistoryServer, or TimelineServer that provides application-specific information. The URL uses the internal hostname, and requires a proxy server for resolution and, possibly, access.
vcore_seconds: i64Optional. The cumulative CPU time consumed by the application for a job, measured in vcore-seconds.
memory_mb_seconds: i64Optional. The cumulative memory usage of the application for a job, measured in mb-seconds.
Implementations
Sourceimpl YarnApplication
impl YarnApplication
Sourcepub fn set_progress<T: Into<f32>>(self, v: T) -> Self
pub fn set_progress<T: Into<f32>>(self, v: T) -> Self
Sourcepub fn set_tracking_url<T: Into<String>>(self, v: T) -> Self
pub fn set_tracking_url<T: Into<String>>(self, v: T) -> Self
Sets the value of tracking_url.
Example
let x = YarnApplication::new().set_tracking_url("example");Sourcepub fn set_vcore_seconds<T: Into<i64>>(self, v: T) -> Self
pub fn set_vcore_seconds<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_memory_mb_seconds<T: Into<i64>>(self, v: T) -> Self
pub fn set_memory_mb_seconds<T: Into<i64>>(self, v: T) -> Self
Sets the value of memory_mb_seconds.
Example
let x = YarnApplication::new().set_memory_mb_seconds(42);Trait Implementations
Sourceimpl Clone for YarnApplication
impl Clone for YarnApplication
Sourcefn clone(&self) -> YarnApplication
fn clone(&self) -> YarnApplication
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for YarnApplication
impl Debug for YarnApplication
Sourceimpl Default for YarnApplication
impl Default for YarnApplication
Sourcefn default() -> YarnApplication
fn default() -> YarnApplication
Sourceimpl Message for YarnApplication
impl Message for YarnApplication
Sourceimpl PartialEq for YarnApplication
impl PartialEq for YarnApplication
impl StructuralPartialEq for YarnApplication