#[non_exhaustive]pub struct OrderedJob {
pub step_id: String,
pub labels: HashMap<String, String>,
pub scheduling: Option<JobScheduling>,
pub prerequisite_step_ids: Vec<String>,
pub job_type: Option<JobType>,
/* private fields */
}Expand description
A job executed by the workflow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.step_id: StringRequired. The step id. The id must be unique among all jobs within the template.
The step id is used as prefix for job id, as job
goog-dataproc-workflow-step-id label, and in
prerequisiteStepIds
field from other steps.
The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of between 3 and 50 characters.
labels: HashMap<String, String>Optional. The labels to associate with this job.
Label keys must be between 1 and 63 characters long, and must conform to the following regular expression: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
Label values must be between 1 and 63 characters long, and must conform to the following regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
No more than 32 labels can be associated with a given job.
scheduling: Option<JobScheduling>Optional. Job scheduling configuration.
prerequisite_step_ids: Vec<String>Optional. The optional list of prerequisite job step_ids. If not specified, the job will start at the beginning of workflow.
job_type: Option<JobType>Required. The job definition.
Implementations
Sourceimpl OrderedJob
impl OrderedJob
pub fn new() -> Self
Sourcepub fn set_step_id<T: Into<String>>(self, v: T) -> Self
pub fn set_step_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_scheduling<T>(self, v: T) -> Selfwhere
T: Into<JobScheduling>,
pub fn set_scheduling<T>(self, v: T) -> Selfwhere
T: Into<JobScheduling>,
Sets the value of scheduling.
Example
use google_cloud_dataproc_v1::model::JobScheduling;
let x = OrderedJob::new().set_scheduling(JobScheduling::default()/* use setters */);Sourcepub fn set_or_clear_scheduling<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobScheduling>,
pub fn set_or_clear_scheduling<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobScheduling>,
Sets or clears the value of scheduling.
Example
use google_cloud_dataproc_v1::model::JobScheduling;
let x = OrderedJob::new().set_or_clear_scheduling(Some(JobScheduling::default()/* use setters */));
let x = OrderedJob::new().set_or_clear_scheduling(None::<JobScheduling>);Sourcepub fn set_prerequisite_step_ids<T, V>(self, v: T) -> Self
pub fn set_prerequisite_step_ids<T, V>(self, v: T) -> Self
Sets the value of prerequisite_step_ids.
Example
let x = OrderedJob::new().set_prerequisite_step_ids(["a", "b", "c"]);Sourcepub fn set_job_type<T: Into<Option<JobType>>>(self, v: T) -> Self
pub fn set_job_type<T: Into<Option<JobType>>>(self, v: T) -> Self
Sourcepub fn hadoop_job(&self) -> Option<&Box<HadoopJob>>
pub fn hadoop_job(&self) -> Option<&Box<HadoopJob>>
The value of job_type
if it holds a HadoopJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_hadoop_job<T: Into<Box<HadoopJob>>>(self, v: T) -> Self
pub fn set_hadoop_job<T: Into<Box<HadoopJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a HadoopJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::HadoopJob;
let x = OrderedJob::new().set_hadoop_job(HadoopJob::default()/* use setters */);
assert!(x.hadoop_job().is_some());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn spark_job(&self) -> Option<&Box<SparkJob>>
pub fn spark_job(&self) -> Option<&Box<SparkJob>>
The value of job_type
if it holds a SparkJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_spark_job<T: Into<Box<SparkJob>>>(self, v: T) -> Self
pub fn set_spark_job<T: Into<Box<SparkJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a SparkJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::SparkJob;
let x = OrderedJob::new().set_spark_job(SparkJob::default()/* use setters */);
assert!(x.spark_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn pyspark_job(&self) -> Option<&Box<PySparkJob>>
pub fn pyspark_job(&self) -> Option<&Box<PySparkJob>>
The value of job_type
if it holds a PysparkJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_pyspark_job<T: Into<Box<PySparkJob>>>(self, v: T) -> Self
pub fn set_pyspark_job<T: Into<Box<PySparkJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a PysparkJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::PySparkJob;
let x = OrderedJob::new().set_pyspark_job(PySparkJob::default()/* use setters */);
assert!(x.pyspark_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn hive_job(&self) -> Option<&Box<HiveJob>>
pub fn hive_job(&self) -> Option<&Box<HiveJob>>
The value of job_type
if it holds a HiveJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_hive_job<T: Into<Box<HiveJob>>>(self, v: T) -> Self
pub fn set_hive_job<T: Into<Box<HiveJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a HiveJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::HiveJob;
let x = OrderedJob::new().set_hive_job(HiveJob::default()/* use setters */);
assert!(x.hive_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn pig_job(&self) -> Option<&Box<PigJob>>
pub fn pig_job(&self) -> Option<&Box<PigJob>>
The value of job_type
if it holds a PigJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_pig_job<T: Into<Box<PigJob>>>(self, v: T) -> Self
pub fn set_pig_job<T: Into<Box<PigJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a PigJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::PigJob;
let x = OrderedJob::new().set_pig_job(PigJob::default()/* use setters */);
assert!(x.pig_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn spark_r_job(&self) -> Option<&Box<SparkRJob>>
pub fn spark_r_job(&self) -> Option<&Box<SparkRJob>>
The value of job_type
if it holds a SparkRJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_spark_r_job<T: Into<Box<SparkRJob>>>(self, v: T) -> Self
pub fn set_spark_r_job<T: Into<Box<SparkRJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a SparkRJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::SparkRJob;
let x = OrderedJob::new().set_spark_r_job(SparkRJob::default()/* use setters */);
assert!(x.spark_r_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn spark_sql_job(&self) -> Option<&Box<SparkSqlJob>>
pub fn spark_sql_job(&self) -> Option<&Box<SparkSqlJob>>
The value of job_type
if it holds a SparkSqlJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_spark_sql_job<T: Into<Box<SparkSqlJob>>>(self, v: T) -> Self
pub fn set_spark_sql_job<T: Into<Box<SparkSqlJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a SparkSqlJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::SparkSqlJob;
let x = OrderedJob::new().set_spark_sql_job(SparkSqlJob::default()/* use setters */);
assert!(x.spark_sql_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn presto_job(&self) -> Option<&Box<PrestoJob>>
pub fn presto_job(&self) -> Option<&Box<PrestoJob>>
The value of job_type
if it holds a PrestoJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_presto_job<T: Into<Box<PrestoJob>>>(self, v: T) -> Self
pub fn set_presto_job<T: Into<Box<PrestoJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a PrestoJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::PrestoJob;
let x = OrderedJob::new().set_presto_job(PrestoJob::default()/* use setters */);
assert!(x.presto_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.trino_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn trino_job(&self) -> Option<&Box<TrinoJob>>
pub fn trino_job(&self) -> Option<&Box<TrinoJob>>
The value of job_type
if it holds a TrinoJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_trino_job<T: Into<Box<TrinoJob>>>(self, v: T) -> Self
pub fn set_trino_job<T: Into<Box<TrinoJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a TrinoJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::TrinoJob;
let x = OrderedJob::new().set_trino_job(TrinoJob::default()/* use setters */);
assert!(x.trino_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.flink_job().is_none());Sourcepub fn flink_job(&self) -> Option<&Box<FlinkJob>>
pub fn flink_job(&self) -> Option<&Box<FlinkJob>>
The value of job_type
if it holds a FlinkJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_flink_job<T: Into<Box<FlinkJob>>>(self, v: T) -> Self
pub fn set_flink_job<T: Into<Box<FlinkJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a FlinkJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_dataproc_v1::model::FlinkJob;
let x = OrderedJob::new().set_flink_job(FlinkJob::default()/* use setters */);
assert!(x.flink_job().is_some());
assert!(x.hadoop_job().is_none());
assert!(x.spark_job().is_none());
assert!(x.pyspark_job().is_none());
assert!(x.hive_job().is_none());
assert!(x.pig_job().is_none());
assert!(x.spark_r_job().is_none());
assert!(x.spark_sql_job().is_none());
assert!(x.presto_job().is_none());
assert!(x.trino_job().is_none());Trait Implementations
Sourceimpl Clone for OrderedJob
impl Clone for OrderedJob
Sourcefn clone(&self) -> OrderedJob
fn clone(&self) -> OrderedJob
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more