#[non_exhaustive]pub struct TemplateParameter {
pub name: String,
pub fields: Vec<String>,
pub description: String,
pub validation: Option<ParameterValidation>,
/* private fields */
}Expand description
A configurable parameter that replaces one or more fields in the template. Parameterizable fields:
- Labels
- File uris
- Job properties
- Job arguments
- Script variables
- Main class (in HadoopJob and SparkJob)
- Zone (in ClusterSelector)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Parameter name. The parameter name is used as the key, and paired with the parameter value, which are passed to the template when the template is instantiated. The name must contain only capital letters (A-Z), numbers (0-9), and underscores (_), and must not start with a number. The maximum length is 40 characters.
fields: Vec<String>Required. Paths to all fields that the parameter replaces. A field is allowed to appear in at most one parameter’s list of field paths.
A field path is similar in syntax to a
google.protobuf.FieldMask. For example, a
field path that references the zone field of a workflow template’s cluster
selector would be specified as placement.clusterSelector.zone.
Also, field paths can reference fields using the following syntax:
-
Values in maps can be referenced by key:
- labels[‘key’]
- placement.clusterSelector.clusterLabels[‘key’]
- placement.managedCluster.labels[‘key’]
- placement.clusterSelector.clusterLabels[‘key’]
- jobs[‘step-id’].labels[‘key’]
-
Jobs in the jobs list can be referenced by step-id:
- jobs[‘step-id’].hadoopJob.mainJarFileUri
- jobs[‘step-id’].hiveJob.queryFileUri
- jobs[‘step-id’].pySparkJob.mainPythonFileUri
- jobs[‘step-id’].hadoopJob.jarFileUris[0]
- jobs[‘step-id’].hadoopJob.archiveUris[0]
- jobs[‘step-id’].hadoopJob.fileUris[0]
- jobs[‘step-id’].pySparkJob.pythonFileUris[0]
-
Items in repeated fields can be referenced by a zero-based index:
- jobs[‘step-id’].sparkJob.args[0]
-
Other examples:
- jobs[‘step-id’].hadoopJob.properties[‘key’]
- jobs[‘step-id’].hadoopJob.args[0]
- jobs[‘step-id’].hiveJob.scriptVariables[‘key’]
- jobs[‘step-id’].hadoopJob.mainJarFileUri
- placement.clusterSelector.zone
It may not be possible to parameterize maps and repeated fields in their entirety since only individual map values and individual items in repeated fields can be referenced. For example, the following field paths are invalid:
- placement.clusterSelector.clusterLabels
- jobs[‘step-id’].sparkJob.args
description: StringOptional. Brief description of the parameter. Must not exceed 1024 characters.
validation: Option<ParameterValidation>Optional. Validation rules to be applied to this parameter’s value.
Implementations
Sourceimpl TemplateParameter
impl TemplateParameter
pub fn new() -> Self
Sourcepub fn set_fields<T, V>(self, v: T) -> Self
pub fn set_fields<T, V>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = TemplateParameter::new().set_description("example");Sourcepub fn set_validation<T>(self, v: T) -> Selfwhere
T: Into<ParameterValidation>,
pub fn set_validation<T>(self, v: T) -> Selfwhere
T: Into<ParameterValidation>,
Sets the value of validation.
Example
use google_cloud_dataproc_v1::model::ParameterValidation;
let x = TemplateParameter::new().set_validation(ParameterValidation::default()/* use setters */);Sourcepub fn set_or_clear_validation<T>(self, v: Option<T>) -> Selfwhere
T: Into<ParameterValidation>,
pub fn set_or_clear_validation<T>(self, v: Option<T>) -> Selfwhere
T: Into<ParameterValidation>,
Sets or clears the value of validation.
Example
use google_cloud_dataproc_v1::model::ParameterValidation;
let x = TemplateParameter::new().set_or_clear_validation(Some(ParameterValidation::default()/* use setters */));
let x = TemplateParameter::new().set_or_clear_validation(None::<ParameterValidation>);Trait Implementations
Sourceimpl Clone for TemplateParameter
impl Clone for TemplateParameter
Sourcefn clone(&self) -> TemplateParameter
fn clone(&self) -> TemplateParameter
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more